@@ -79,25 +79,8 @@ def classification_evaluation_cv(results, X, y, cv=10, n_jobs=10):
 
 # %% classification evaluation for a single model: test set
 def classification_evaluation_test_(selected_model, X_test, y_test):
-    # check if it is binary or multiclass
-    task = "binary"
-    if len(np.unique(y_test)) > 2:
-        task = "multiclass"
-
-    # y_true, y_hat, y_hat_prob
-    y_true = y_test
-    y_hat = selected_model.predict(X_test)
-    y_hat_prob = None
-    if hasattr(selected_model, "predict_proba"):
-        if len(np.unique(y_test)) > 2:
-            y_hat_prob = selected_model.predict_proba(X_test)
-        else:
-            y_hat_prob = selected_model.predict_proba(X_test)[:, 1]
-
-    # check if it is the output of grandint boosting model
-    if hasattr(selected_model, "label_encoder_"):
-        label_encoder = selected_model.label_encoder_
-        y_hat = label_encoder.inverse_transform(y_hat)
+    # get task, y_true, y_hat, y_hat_prob
+    task, y_true, y_hat, y_hat_prob = predict_test_set_(selected_model, X_test, y_test)
 
     # metrics on the test set
     if task == "binary":
@@ -108,8 +91,53 @@ def classification_evaluation_test_(selected_model, X_test, y_test):
     return model_metrics
 
 
+# def a fun to predict the test set
+def predict_test_set_(selected_model, X_test, y_test):
+    # check if it is binary or multiclass
+    task = "binary"
+    if len(np.unique(y_test)) > 2:
+        task = "multiclass"
+
+    # y_true, y_hat, y_hat_prob
+    y_true = y_test
+    y_hat = selected_model.predict(X_test)
+    y_hat_prob = None
+
+    # get the probability estimation
+    if hasattr(selected_model, "predict_proba"):
+        if len(np.unique(y_test)) > 2:
+            y_hat_prob = selected_model.predict_proba(X_test)
+        else:
+            y_hat_prob = selected_model.predict_proba(X_test)[:, 1]
+
+    # for svm, it is not probability but it can still be used for generate AUC
+    if hasattr(selected_model, "decision_function") and task == "binary":
+        y_hat_prob = selected_model.decision_function(X_test)
+
+    # check if it is the output of grandint boosting model
+    if hasattr(selected_model, "label_encoder_"):
+        label_encoder = selected_model.label_encoder_
+        y_hat = label_encoder.inverse_transform(y_hat)
+
+    return task, y_true, y_hat, y_hat_prob
+
+
 # %% classification evaluation for a single model: K-Fold CV
 def classification_evaluation_cv_(selected_model, X, y, cv=10, n_jobs=10):
+    # get task, y_true, y_hat, y_hat_prob
+    task, y_true, y_hat, y_hat_prob = predict_cv_set_(selected_model, X, y, cv, n_jobs)
+
+    # metrics on the test set
+    if task == "binary":
+        model_metrics = binary_evaluation_base_(y_true, y_hat, y_hat_prob)
+    elif task == "multiclass":
+        model_metrics = multiclass_evaluation_base_(y_true, y_hat, y_hat_prob)
+
+    return model_metrics
+
+
+# def a fun to predict the X y in the CV way
+def predict_cv_set_(selected_model, X, y, cv, n_jobs):
     # check it is binary or multiclass
     task = "binary"
     if len(np.unique(y)) > 2:
@@ -130,6 +158,8 @@ def classification_evaluation_cv_(selected_model, X, y, cv=10, n_jobs=10):
         )
 
     y_hat_prob = None
+
+    # probability estimation
     if hasattr(selected_model, "predict_proba"):
         if len(np.unique(y)) > 2:
             y_hat_prob = model_selection.cross_val_predict(
@@ -140,13 +170,12 @@ def classification_evaluation_cv_(selected_model, X, y, cv=10, n_jobs=10):
                 selected_model, X, y, cv=cv, n_jobs=n_jobs, method="predict_proba"
             )[:, 1]
 
-    # metrics on the test set
-    if task == "binary":
-        model_metrics = binary_evaluation_base_(y_true, y_hat, y_hat_prob)
-    elif task == "multiclass":
-        model_metrics = multiclass_evaluation_base_(y_true, y_hat, y_hat_prob)
-
-    return model_metrics
+    # non probability estimation for svm model
+    if hasattr(selected_model, "decision_function") and task == "binary":
+        y_hat_prob = model_selection.cross_val_predict(
+            selected_model, X, y, cv=cv, n_jobs=n_jobs, method="decision_function"
+        )
+    return task, y_true, y_hat, y_hat_prob
 
 
 # %% base evaluators
