@@ -16,6 +16,7 @@ from sklearn import metrics
 from sklearn import ensemble
 from sklearn.preprocessing import LabelEncoder
 from sklearn.utils import class_weight
+from sklearn.inspection import permutation_importance
 
 # using xgboost for gradient boosting
 from xgboost import XGBClassifier
@@ -107,7 +108,7 @@ def train_classification_models(
         result["clf_linear"] = logistic_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the logistic linear model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the logistic linear model. \n {'-' * 50}"
             )
 
     # fit logistic regression model with lasso penalty
@@ -128,7 +129,7 @@ def train_classification_models(
         result["clf_lasso"] = logistic_lasso_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the logistic linear model with"
+                f"{round(toc, 4)} seconds were taken to select and fit the logistic linear model with"
                 f" lasso penalty. \n {'-' * 50}"
             )
 
@@ -150,7 +151,7 @@ def train_classification_models(
         result["clf_ridge"] = logistic_ridge_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the logistic linear model"
+                f"{round(toc, 4)} seconds were taken to select and fit the logistic linear model"
                 f" with ridge penalty. \n {'-' * 50}"
             )
 
@@ -172,7 +173,7 @@ def train_classification_models(
         result["clf_elasticNet"] = logistic_elasticNet_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the logistic linear model"
+                f"{round(toc, 4)} seconds were taken to select and fit the logistic linear model"
                 f" with elasticnet penalty. \n {'-' * 50}"
             )
 
@@ -194,7 +195,7 @@ def train_classification_models(
         result["clf_svm"] = svm_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the svm model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the svm model. \n {'-' * 50}"
             )
 
     # fit nn model
@@ -217,7 +218,7 @@ def train_classification_models(
         result["clf_nn"] = nn_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the neural network model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the neural network model. \n {'-' * 50}"
             )
 
     # fit gradient boosting model
@@ -232,7 +233,7 @@ def train_classification_models(
         result["clf_gb"] = gb_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the gradient boosting model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the gradient boosting model. \n {'-' * 50}"
             )
 
     # fit random forest model
@@ -247,7 +248,7 @@ def train_classification_models(
         result["clf_rf"] = rf_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the random forest model are done. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the random forest model are done. \n {'-' * 50}"
             )
 
     return result
@@ -575,11 +576,8 @@ def train_svm(X, y, scaler, decomposer, cv=10, n_jobs=10, n_trials=30, verbose=0
     svm_selected.fit(X, y)
 
     # feature importance
-    feature_importance = None
-    if hasattr(svm_selected, "coef_"):
-        feature_importance = svm_selected.coef_.transpose()
-        if len(np.unique(y)) == 2:
-            feature_importance = feature_importance.flatten()
+    per_importance = permutation_importance(svm_selected, X, y)
+    feature_importance = per_importance["importances_mean"]
 
     # selected hyper parameter
     selected_hyperparameter = svm_study.best_params
@@ -631,7 +629,7 @@ def train_nn(
         layers = []
         for i in range(n_layers):
             # number of units
-            n_units = trial.suggest_int("n_units_layer_{}".format(i), 4, 256, log=True)
+            n_units = trial.suggest_int("n_units_layer_{}".format(i), 4, 512, log=True)
             layers.append(n_units)
         hidden_layer_sizes = tuple(layers)
         alpha = trial.suggest_loguniform("alpha", 1e-8, 1e0)
@@ -715,7 +713,8 @@ def train_nn(
     nn_selected.fit(X, y)
 
     # feature importance
-    feature_importance = None
+    per_importance = permutation_importance(nn_selected, X, y)
+    feature_importance = per_importance["importances_mean"]
 
     # selected hyper parameter
     selected_hyperparameter = best_params
