@@ -15,6 +15,7 @@ from sklearn import metrics
 from sklearn import ensemble
 from sklearn import svm
 from sklearn import neural_network as nn
+from sklearn.inspection import permutation_importance
 
 # gradient boosting model
 from xgboost import XGBRegressor
@@ -104,7 +105,7 @@ def train_regression_models(
         result["reg_linear"] = reg_linear_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the linear model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the linear model. \n {'-' * 50}"
             )
 
     # fit linear regression model with lasso penalty
@@ -124,7 +125,7 @@ def train_regression_models(
         result["reg_lasso"] = lasso_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the linear model with"
+                f"{round(toc, 4)} seconds were taken to select and fit the linear model with"
                 f" lasso penalty. \n {'-' * 50}"
             )
 
@@ -139,7 +140,7 @@ def train_regression_models(
         result["reg_ridge"] = ridge_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the linear model"
+                f"{round(toc, 4)} seconds were taken to select and fit the linear model"
                 f" with ridge penalty. \n {'-' * 50}"
             )
 
@@ -160,7 +161,7 @@ def train_regression_models(
         result["reg_elasticNet"] = elasticNet_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the linear model"
+                f"{round(toc, 4)} seconds were taken to select and fit the linear model"
                 f" with elasticnet penalty. \n {'-' * 50}"
             )
 
@@ -182,7 +183,7 @@ def train_regression_models(
         result["reg_svm"] = svm_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the svm model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the svm model. \n {'-' * 50}"
             )
 
     # fit nn model
@@ -205,7 +206,7 @@ def train_regression_models(
         result["reg_nn"] = nn_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the neural network model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the neural network model. \n {'-' * 50}"
             )
     # fit gradient boosting model
     if "reg_gb" in reg_models:
@@ -219,7 +220,7 @@ def train_regression_models(
         result["reg_gb"] = gb_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the gradient boosting model. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the gradient boosting model. \n {'-' * 50}"
             )
 
     # fit random forest model
@@ -234,7 +235,7 @@ def train_regression_models(
         result["reg_rf"] = rf_model
         if verbose == 1:
             print(
-                f"{round(toc, 4)} seconds taken to select and fit the random forest model are done. \n {'-' * 50}"
+                f"{round(toc, 4)} seconds were taken to select and fit the random forest model are done. \n {'-' * 50}"
             )
 
     return result
@@ -466,9 +467,8 @@ def train_svm(
     svm_selected.fit(X, y)
 
     # feature importance
-    feature_importance = None
-    if hasattr(svm_selected, "coef_"):
-        feature_importance = svm_selected.coef_
+    per_importance = permutation_importance(svm_selected, X, y)
+    feature_importance = per_importance["importances_mean"]
 
     # selected hyper parameter
     selected_hyperparameter = svm_study.best_params
@@ -520,7 +520,7 @@ def train_nn(
         layers = []
         for i in range(n_layers):
             # number of units
-            n_units = trial.suggest_int("n_units_layer_{}".format(i), 4, 256, log=True)
+            n_units = trial.suggest_int("n_units_layer_{}".format(i), 4, 512, log=True)
             layers.append(n_units)
         hidden_layer_sizes = tuple(layers)
         alpha = trial.suggest_loguniform("alpha", 1e-8, 1e0)
@@ -591,7 +591,8 @@ def train_nn(
     nn_selected.fit(X, y)
 
     # feature importance
-    feature_importance = None
+    per_importance = permutation_importance(nn_selected, X, y)
+    feature_importance = per_importance["importances_mean"]
 
     # selected hyper parameter
     selected_hyperparameter = best_params
